Documentation
¶
Index ¶
- type Simulation
- func (s *Simulation) HandleEvents(win *pixelgl.Window, dt float64)
- func (s *Simulation) ParseInputFile(filePath string)
- func (s *Simulation) ParseOutputFile(filePath string)
- func (s *Simulation) Run(imd *imdraw.IMDraw)
- func (s *Simulation) Start()
- func (s *Simulation) Stop()
- func (s *Simulation) Toggle()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Simulation ¶
type Simulation struct {
Stopped bool
Ended bool
LastStep int
Step int
Score int
Trips []*ghashcode.Trip
Vehicles []*ghashcode.Vehicle
// contains filtered or unexported fields
}
Simulation is a struct handling information about the simulation
func NewSimulation ¶
func NewSimulation() *Simulation
NewSimulation a constructor for the simulation which set the default values
func (*Simulation) HandleEvents ¶
func (s *Simulation) HandleEvents(win *pixelgl.Window, dt float64)
func (*Simulation) ParseInputFile ¶
func (s *Simulation) ParseInputFile(filePath string)
ParseInputFile it parse the examples It's the file you send to the Google Hashcode Judge System
func (*Simulation) ParseOutputFile ¶
func (s *Simulation) ParseOutputFile(filePath string)
ParseOutputFile it parse the file that your program has created It's the file you send to the Google Hashcode Judge System
func (*Simulation) Run ¶
func (s *Simulation) Run(imd *imdraw.IMDraw)
func (*Simulation) Start ¶
func (s *Simulation) Start()
func (*Simulation) Stop ¶
func (s *Simulation) Stop()
func (*Simulation) Toggle ¶
func (s *Simulation) Toggle()
Click to show internal directories.
Click to hide internal directories.